function [p] = gui_eeg_open(p,command,parent)

% gui_eeg_open - Load an EEG data file into matlab workspace
% 
% Usage: [p] = gui_eeg_open(p,[command],[parent])
%
% p is a structure, generated by 'eeg_toolbox_defaults'
% command is either 'init' or 'load'
% parent is a handle to the gui that calls this gui, useful
% for updating the UserData field of the parent from this gui.
% The p structure is returned to the parent when the parent 
% handle is given.
%

% $Revision: 1.1 $ $Date: 2009-04-28 22:13:56 $

% Licence:  GNU GPL, no express or implied warranties
% History:  01/2002, Darren.Weber_at_radiology.ucsf.edu
%           08/2002, Darren.Weber_at_radiology.ucsf.edu
%                    added EMSE avg handling
%                    added interpolation of zero point option
%           10/2003, Darren.Weber_at_radiology.ucsf.edu
%                    created gui_avg_open and adapted this
%                    function to handle CNT/EEG data formats
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if ~exist('p','var'),
 [p] = eeg_toolbox_defaults;
elseif isempty(p),
 [p] = eeg_toolbox_defaults;
end

if ~exist('command','var'), command = 'init'; end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Paint the GUI
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

switch command,
  
  case 'init',
    
    if exist('parent','var'),
      EEGOpen = INIT(p,parent);
    else
      EEGOpen = INIT(p,'');
    end
    
  case 'plot',
    
    EEGOpen = get(gcbf,'Userdata');
    
    EEGOpen.p = cnt_open(EEGOpen.p,EEGOpen.gui);
    set(EEGOpen.gui,'Userdata',EEGOpen); % update GUI with CNT data
    
   [p] = gui_updateparent(EEGOpen,0);
    
    if isequal(get(EEGOpen.handles.Bhold,'Value'),0),
      close gcbf;
      if isfield(EEGOpen,'parent'),
        parent = EEGOpen.parent.gui;
      else
        parent = [];
      end
    else
      parent = EEGOpen.gui;
    end
    
    plotfig = figure('Name',EEGOpen.p.cnt.file,...
      'NumberTitle','off',...
      'UserData',EEGOpen.p);
    movegui(plotfig,'center');
    
    plot(EEGOpen.p.cnt.timeArray,EEGOpen.p.cnt.data); axis tight;
    eeg_plot_metric;
    
    if isempty(parent), [Xpoint,Ypoint] = eeg_crosshair('init',EEGOpen.p);
    else                [Xpoint,Ypoint] = eeg_crosshair('init',EEGOpen.p,parent);
    end
    
  case 'save',
    
    fprintf('\nGUI_EEG_OPEN: Save As not implemented yet.\n');
    
  case 'return',
    
    EEGOpen = get(gcbf,'Userdata');
    
    set(EEGOpen.gui,'Pointer','watch');
    
    EEGOpen.p = cnt_open(EEGOpen.p);
    
    set(EEGOpen.gui,'Pointer','arrow');
    
    if isequal(get(EEGOpen.handles.Bhold,'Value'),1),
     [p] = gui_updateparent(EEGOpen,0);
    else
     [p] = gui_updateparent(EEGOpen);
      close gcbf;
    end
    
  otherwise,
    
    EEGOpen = get(gcbf,'Userdata');
    GUI.parent = EEGOpen.parent;
    gui_updateparent(GUI);
    close gcbf;
    
end

return



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [EEGOpen] = INIT(p,parent)
% GUI General Parameters

GUIwidth  = 500;
GUIheight = 120;

version = '$Revision: 1.1 $';
name = sprintf('EEG File Open [v %s]\n',version(11:15));

GUI = figure('Name',name,'Tag','EEG_OPEN',...
  'NumberTitle','off',...
  'MenuBar','none','Position',[1 1 GUIwidth GUIheight]);
movegui(GUI,'center');

Font.FontName   = 'Helvetica';
Font.FontUnits  = 'Pixels';
Font.FontSize   = 12;
Font.FontWeight = 'normal';
Font.FontAngle  = 'normal';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% CNT Data Selection and Parameters

G.Title_data = uicontrol('Parent',GUI,'Style','text','Units','Normalized',Font, ...
  'Position',[.01 .75 .17 .2],...
  'String','Data Type:','HorizontalAlignment','left');

switch lower(p.cnt.type),
  case 'scan4x_cnt',  cntType = 1;
  case 'scan3x_cnt',  cntType = 2;
  otherwise,          cntType = 1;
end

%  'String',{'ASCII_CNT' 'Scan4x_CNT' 'Scan3x_CNT' 'EEGLAB'},'Value',cntType,...

G.PcntType = uicontrol('Tag','PcntType','Parent',GUI,'Style','popupmenu',...
  'Units','Normalized',Font,  ...
  'Position',[.20 .75 .2 .2],...
  'String',{'scan4x_cnt' 'scan3x_cnt'},'Value',cntType,...
  'Callback',strcat('EEGOpen = get(gcbf,''Userdata'');',...
  'EEGOpen.p.cnt.type = popupstr(EEGOpen.handles.PcntType);',...
  'set(gcbf,''Userdata'',EEGOpen); clear EEGOpen;'));

G.Title_path = uicontrol('Parent',GUI,'Style','text','Units','Normalized',Font, ...
  'Position',[.01 .50 .17 .2],...
  'String','Path','HorizontalAlignment','left');
G.EcntPath = uicontrol('Parent',GUI,'Style','edit','Units','Normalized',Font,  ...
  'Position',[.20 .50 .58 .2], 'String',p.cnt.path,...
  'Callback',strcat('EEGOpen = get(gcbf,''Userdata'');',...
  'EEGOpen.p.cnt.path = get(EEGOpen.handles.EcntPath,''String'');',...
  'set(gcbf,''Userdata'',EEGOpen); clear EEGOpen;'));

G.Title_file = uicontrol('Parent',GUI,'Style','text','Units','Normalized',Font, ...
  'Position',[.01 .25 .17 .2],...
  'String','File','HorizontalAlignment','left');
G.EcntFile = uicontrol('Parent',GUI,'Style','edit','Units','Normalized',Font,  ...
  'Position',[.20 .25 .58 .2], 'String',p.cnt.file,...
  'Callback',strcat('EEGOpen = get(gcbf,''Userdata'');',...
  'EEGOpen.p.cnt.file = get(EEGOpen.handles.EcntFile,''String'');',...
  'set(gcbf,''Userdata'',EEGOpen); clear EEGOpen;'));

Font.FontWeight = 'bold';

% BROWSE: Look for the data
browsecommand = strcat('EEGOpen = get(gcbf,''Userdata'');',...
  'cd(EEGOpen.p.cnt.path);',...
  '[file, path] = uigetfile(',...
  '{''*.cnt'', ''NeuroScan (*.cnt)'';', ...
  ' ''*.*'',   ''All Files (*.*)''},', ...
  '''Select EEG File'');',...
  'if ~isequal(path,0), EEGOpen.p.cnt.path = path; end;',...
  'if ~isequal(file,0), EEGOpen.p.cnt.file = file; end;',...
  'set(EEGOpen.handles.EcntPath,''String'',EEGOpen.p.cnt.path);',...
  'set(EEGOpen.handles.EcntFile,''String'',EEGOpen.p.cnt.file);',...
  'set(gcbf,''Userdata'',EEGOpen); clear EEGOpen file path;');
G.BcntFile = uicontrol('Parent',GUI,'Style','pushbutton','Units','Normalized',Font, ...
  'Position',[.01 .01 .17 .2], 'String','BROWSE',...
  'BackgroundColor',[0.8 0.8 0.0],...
  'ForegroundColor', [1 1 1], 'HorizontalAlignment', 'center',...
  'Callback', browsecommand );

% PLOT: Load & plot the data!
G.Bplot = uicontrol('Parent',GUI,'Style','pushbutton','Units','Normalized', Font, ...
  'Position',[.20 .01 .18 .2],...
  'String','PLOT','BusyAction','queue',...
  'TooltipString','Plot the EEG data and return p struct.',...
  'BackgroundColor',[0.0 0.5 0.0],...
  'ForegroundColor', [1 1 1], 'HorizontalAlignment', 'center',...
  'Callback',strcat('EEGOpen = get(gcbf,''Userdata'');',...
  'p = gui_eeg_open(EEGOpen.p,''plot'');',...
  'clear EEGOpen;'));

% Save As
G.Bsave = uicontrol('Parent',GUI,'Style','pushbutton','Units','Normalized', Font, ...
  'Position',[.40 .01 .18 .2],'HorizontalAlignment', 'center',...
  'String','SAVE AS','TooltipString','EEG File Conversion Tool (not implemented yet)',...
  'BusyAction','queue',...
  'Visible','off',...
  'BackgroundColor',[0.0 0.0 0.75],...
  'ForegroundColor', [1 1 1], 'HorizontalAlignment', 'center',...
  'Callback',strcat('EEGOpen = get(gcbf,''Userdata'');',...
  'p = gui_eeg_open(EEGOpen.p,''save'');',...
  'clear EEGOpen;'));

% Quit, return file parameters
G.Breturn = uicontrol('Parent',GUI,'Style','pushbutton','Units','Normalized', Font, ...
  'Position',[.60 .01 .18 .2],...
  'String','RETURN','BusyAction','queue',...
  'TooltipString','Return p struct to workspace and parent GUI.',...
  'BackgroundColor',[0.75 0.0 0.0],...
  'ForegroundColor', [1 1 1], 'HorizontalAlignment', 'center',...
  'Callback',strcat('EEGOpen = get(gcbf,''Userdata'');',...
  'p = gui_eeg_open(EEGOpen.p,''return'');',...
  'clear EEGOpen;'));

% Cancel
G.Bcancel = uicontrol('Parent',GUI,'Style','pushbutton','Units','Normalized', Font, ...
  'Position',[.80 .01 .18 .2],...
  'String','CANCEL','BusyAction','queue',...
  'TooltipString','Close, do not return parameters.',...
  'BackgroundColor',[0.75 0.0 0.0],...
  'ForegroundColor', [1 1 1], 'HorizontalAlignment', 'center',...
  'Callback',strcat('EEGOpen = get(gcbf,''Userdata'');',...
  'p = gui_eeg_open(EEGOpen.p,''cancel'');',...
  'clear EEGOpen;'));

% Hold GUI Open checkbox
G.Bhold = uicontrol('Parent',GUI,'Style','checkbox','Units','Normalized', Font, ...
  'Position',[.80 .25 .18 .2],'String','Hold GUI','BusyAction','queue',...
  'TooltipString','EEG File Load GUI remains open after ''Plot'' or ''Return'' commands.',...
  'Value',p.hold,'HorizontalAlignment', 'center');


% Store userdata
if exist('parent','var'), EEGOpen.parent.gui = parent; end
EEGOpen.gui = GUI;          
EEGOpen.handles = G;
EEGOpen.p = p;
set(GUI,'Userdata',EEGOpen);
set(GUI,'HandleVisibility','callback');

return
